@@ -30,7 +30,7 @@ import java.util.List;
  * @see StringOption
  * @see IntegerOption
  * @see BooleanOption
- * @see EnuerationOption
+ * @see EnumerationOption
  * @see Option#string 
  * @see Option#integer 
  * @see Option#bool 
@@ -442,6 +442,7 @@ public abstract class Option<T> {
      */
     public synchronized void force(String value) {
         forced = value;
+        loaded = false;
         reload();
     }
 
